#!/bin/bash

# Keep track of the current directory.
TOP_DIR=$(pwd)


# Global Settings
# ===============

# Configure which package should be download.
if [[ ! $PACKAGE =~ (standard|full) || -z $PACKAGE ]]; then
    PACKAGE="full"
fi

# Configure which action should be taken.
if [[ ! $ACTION =~ (build|upgrade) || -z $ACTION ]]; then
    ACTION="upgrade"
fi

# Configure if source should be keep.
if [[ -z $SOURCE ]]; then
    SOURCE=false
fi

# Configure drush make options.
if [[ -z $MAKE_OPTIONS ]]; then
    MAKE_OPTIONS="--concurrency=8 --contrib-destination=profiles/drustack --no-cache --force-complete"
fi

# Configure drush make file.
if [[ -z $MAKE_FILE ]]; then
    MAKE_FILE="http://drupalcode.org/project/drustack.git/blob_plain/refs/heads/7.x-29.x:/makes/$PACKAGE.make"
fi

# Configure drush make path.
if [[ -z $MAKE_PATH ]]; then
    MAKE_PATH="."
fi


# Global Functions
# ================

function pre_build()
{
    if [[ $ACTION == 'build' ]]; then
        MAKE_OPTIONS="$MAKE_OPTIONS --prepare-install"
    fi
}

function pre_upgrade()
{
    if [[ $ACTION == 'upgrade' ]]; then
        chmod a+w sites/*
        rm -rf profiles/drustack
    fi
}

function pre_source()
{
    if [[ "$SOURCE" == true ]]; then
        MAKE_OPTIONS="$MAKE_OPTIONS --no-gitinfofile --working-copy"
    fi
}

function post_upgrade()
{
    if [[ $ACTION == 'upgrade' ]]; then
        chmod a-w sites/*
    fi
}

function post_package()
{
    if [[ "$SOURCE" == false ]]; then
        rm -rf profiles/drustack/.gitignore

        find profiles/drustack/*/contrib/ -type f -name '*.info' |
        xargs grep -l 'project = "drustack"' |
        while read DATA; do
            TMP=`mktemp`
            head -n -6 $DATA > $TMP
            mv $TMP $DATA
        done
    fi
}

function post_source()
{
    if [[ "$SOURCE" == true ]]; then
        find $TOP_DIR -type d -name '.git' |
        while read DATA; do
            PROJECT=`echo $DATA | sed "s/^.*\/\([^\/]*\)\/\.git/\1/g"`
            cd $DATA/../
            git remote set-url --push origin `whoami`@git.drupal.org:project/$PROJECT.git
            git fetch
            git status
            git remote -v
        done
    fi
}


# Install Packages
# ================

set -o xtrace

cd $TOP_DIR

pre_build
pre_upgrade

#pre_package
pre_source

drush -y make $MAKE_OPTIONS $MAKE_FILE $MAKE_PATH

#post_build
post_upgrade

post_package
post_source
